SBException class

Inheritance

Constructors

SBException(String name, String reason, {List<StackTraceElement>? stackTrace, List<String>? callStackSymbols, Json? json})
SBException.fromError(Object error, StackTrace stackTrace, {String? context})
factory
SBException.fromJson(Json json)
factory

Properties

callStackSymbols List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
orderId int
getter/setter pairinherited
reason String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace List<StackTraceElement>?
getter/setter pair
time DateTime
getter/setter pairinherited
type LogType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Json
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited