MessageException class

Constructors

MessageException(String? name, String? reason, List<StackTraceElement> stackTrace)
MessageException.fromJson(Json json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
reason String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace List<StackTraceElement>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited